/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER, TCSDESIGNER
 * Version: 1.0
 */

using NAnt.Core;
using System;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// This exception is derived from <see cref="BuildException"/>. It is thrown by <see cref="ServerAppTestTask"/>
    /// when any exceptions are caught when executing the task, except for just an exception from the inner task
    /// itself.
    /// </summary>
    public class ServerTaskException : BuildException
    {
        /// <summary>
        /// This variable stores the array of "inner" exceptions. These are the cause exceptions of this exception.
        /// Initialized in constructor, can be null. If not null, elements cannot be null. Immutable.
        /// </summary>
        private readonly Exception[] innerExceptions;

        /// <summary>
        /// This property exposes the array of "inner" exceptions. These are the cause exceptions of this exception.
        /// Initialized in constructor, can be null. If not null, elements cannot be null. Immutable.
        /// </summary>
        /// <value>
        /// Null, or an array of non-null <c>Exception</c> instances.
        /// </value>
        public Exception[] InnerExceptions
        {
            get
            {
                return innerExceptions;
            }
        }

        /// <summary>
        /// Constructs an exception with the message string and inner exceptions.
        /// </summary>
        /// <remarks>
        /// If inner exceptions are specified, the first one of them is reported as the traditional "cause". Remaining
        /// exceptions can only be accessed through the <see cref="InnerExceptions"/> property.
        /// </remarks>
        /// <param name="message">The message to use, can be null.</param>
        /// <param name="innerExceptions">The array of inner exceptions that caused this exception, can be null.
        /// </param>
        public ServerTaskException(string message, Exception[] innerExceptions)
            : base(message, (innerExceptions == null || innerExceptions.Length == 0) ? null : innerExceptions[0])
        {
            this.innerExceptions = innerExceptions;
        }
    }
}
