/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDEVELOPER
 * Version: 1.0
 */

using NUnit.Framework;
using System;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// This class tests <see cref="ServerTaskException"/>, an exception class supporting multiple inner exceptions.
    /// </summary>
    [TestFixture]
    public class TestServerTaskException
    {
        /// <summary>
        /// Tests the two-param constructor with an empty array. This shouldn't really happen, but we check that the
        /// constructor won't barf on that data anyway.
        /// </summary>
        [Test]
        public void TestTwoParamConstructor0()
        {
            Exception[] inner = new Exception[] {};
            ServerTaskException e = new ServerTaskException("test", inner);
            Assert.AreEqual("test", e.Message, "Incorrect message.");
            Assert.AreEqual(null, e.InnerException, "Incorrect inner exception, there should be none.");
            Assert.AreEqual(inner, e.InnerExceptions, "Incorrect inner exceptions.");
        }

        /// <summary>
        /// Tests the two-param constructor with a one-element array.
        /// </summary>
        [Test]
        public void TestTwoParamConstructor1()
        {
            Exception[] inner = new Exception[] { new Exception("TESTING") };
            ServerTaskException e = new ServerTaskException("test", inner);
            Assert.AreEqual("test", e.Message, "Incorrect message.");
            Assert.AreEqual(inner[0], e.InnerException, "Incorrect inner exception (should be the first one).");
            Assert.AreEqual(inner, e.InnerExceptions, "Incorrect inner exceptions.");
        }

        /// <summary>
        /// Tests the two-param constructor with a two-element array.
        /// </summary>
        [Test]
        public void TestTwoParamConstructor2()
        {
            Exception[] inner = new Exception[] { new Exception("TESTING"), new NotSupportedException() };
            ServerTaskException e = new ServerTaskException("test", inner);
            Assert.AreEqual("test", e.Message, "Incorrect message.");
            Assert.AreEqual(inner[0], e.InnerException, "Incorrect inner exception (should be the first one).");
            Assert.AreEqual(inner, e.InnerExceptions, "Incorrect inner exceptions.");
        }
    }
}
